==> pam_flutter-1.3.20.tar.gz: lib/pages/notification_page.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/notification_repository.dart';
import 'package:pam_flutter/widgets/commons/loading_stack.dart';

class NotificationsPage extends StatefulWidget {
  final String baseAPI;

  NotificationsPage({
    required this.baseAPI,
  });

  @override
  State<StatefulWidget> createState() {
    return NotificationsPageState();
  }
}

class NotificationsPageState extends State<NotificationsPage> {
  late NotificationRepository notificationRepository;

  @override
  void initState() {
    super.initState();

    this.notificationRepository = NotificationRepository(
      buildCtx: this.context,
      options:
          NewRepositoryOptions(baseUrl: "${widget.baseAPI}/api/notifications"),
    );
    this.notificationRepository.fetch();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: LoadingStack(
        isLoadingSC: this.notificationRepository.isLoadingSC,
        children: () => [
          Container(
            padding: EdgeInsets.only(
              top: 85 + MediaQuery.of(context).padding.top + 8,
              left: 8,
              right: 8,
            ),
            child: ListView(
              padding: EdgeInsets.only(
                top: 8,
              ),
              children: List.generate(
                  this.notificationRepository.items.length, (index) {
                return Container(
                  height: 108,
                  margin: EdgeInsets.only(
                    bottom: 8,
                  ),
                  padding: EdgeInsets.only(
                    top: 10,
                    bottom: 10,
                    left: 16,
                    right: 16,
                  ),
                  decoration: BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.circular(16),
                  ),
                  child: Column(
                    children: [
                      Container(
                        child: Row(
                          children: [
                            Container(
                              padding: EdgeInsets.all(8),
                              decoration: BoxDecoration(
                                border: Border.all(),
                                shape: BoxShape.circle,
                              ),
                              child: Container(
                                child: Icon(
                                  Icons.notifications_none,
                                  size: 22,
                                ),
                              ),
                            ),
                            Expanded(
                              child: Container(
                                color: Colors.transparent,
                                padding: EdgeInsets.only(
                                  left: 16,
                                  right: 16,
                                ),
                                child: Column(
                                  children: [
                                    Container(
                                      margin: EdgeInsets.only(
                                        bottom: 8,
                                      ),
                                      alignment: Alignment.centerLeft,
                                      child: Text(
                                        this.notificationRepository
                                            .items[index]
                                            .Title,
                                        style: TextStyle(
                                          height: 16,
                                          fontSize: 16,
                                          fontWeight: FontWeight.bold,
                                        ),
                                        maxLines: 1,
                                        overflow: TextOverflow.ellipsis,
                                      ),
                                    ),
                                    Container(
                                      alignment: Alignment.topLeft,
                                      child: Text(
                                        this.notificationRepository
                                            .items[index]
                                            .Message,
                                        style: TextStyle(
                                          color: Colors.grey,
                                          fontSize: 12,
                                          fontWeight: FontWeight.bold,
                                        ),
                                        maxLines: 3,
                                        overflow: TextOverflow.ellipsis,
                                      ),
                                    ),
                                  ],
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                      Container(
                        margin: EdgeInsets.only(
                          top: 8,
                        ),
                        alignment: Alignment.centerRight,
                        child: Text(
                          this.notificationRepository
                              .items[index]
                              .CreatedDate,
                          style: TextStyle(
                            color: Colors.grey.shade600,
                            fontSize: 12,
                            fontWeight: FontWeight.bold,
                          ),
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                        ),
                      ),
                    ],
                  ),
                );
              }),
            ),
          ),
        ],
      ),
    );
  }
}

==> pam_flutter-1.5.44.tar.gz: lib/pages/notification_page.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/notification_repository.dart';
import 'package:pam_flutter/widgets/commons/loading_stack.dart';

class NotificationsPage extends StatefulWidget {
  final String baseAPI;

  NotificationsPage({
    required this.baseAPI,
  });

  @override
  State<StatefulWidget> createState() {
    return _NotificationsPageState();
  }
}

class _NotificationsPageState extends State<NotificationsPage> {
  late NotificationRepository notificationRepository;

  @override
  void initState() {
    super.initState();

    this.notificationRepository = NotificationRepository(
      buildCtx: this.context,
      options:
          NewRepositoryOptions(baseUrl: "${widget.baseAPI}/api/notifications"),
    );
    this.notificationRepository.fetch();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: LoadingStack(
        isLoadingSC: this.notificationRepository.isLoadingSC,
        children: () => [
          Container(
            padding: EdgeInsets.only(
              top: 85 + MediaQuery.of(context).padding.top + 8,
              left: 8,
              right: 8,
            ),
            child: ListView(
              padding: EdgeInsets.only(
                top: 8,
              ),
              children: List.generate(
                  this.notificationRepository.items.length, (index) {
                return Container(
                  height: 108,
                  margin: EdgeInsets.only(
                    bottom: 8,
                  ),
                  padding: EdgeInsets.only(
                    top: 10,
                    bottom: 10,
                    left: 16,
                    right: 16,
                  ),
                  decoration: BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.circular(16),
                  ),
                  child: Column(
                    children: [
                      Container(
                        child: Row(
                          children: [
                            Container(
                              padding: EdgeInsets.all(8),
                              decoration: BoxDecoration(
                                border: Border.all(),
                                shape: BoxShape.circle,
                              ),
                              child: Container(
                                child: Icon(
                                  Icons.notifications_none,
                                  size: 22,
                                ),
                              ),
                            ),
                            Expanded(
                              child: Container(
                                color: Colors.transparent,
                                padding: EdgeInsets.only(
                                  left: 16,
                                  right: 16,
                                ),
                                child: Column(
                                  children: [
                                    Container(
                                      margin: EdgeInsets.only(
                                        bottom: 8,
                                      ),
                                      alignment: Alignment.centerLeft,
                                      child: Text(
                                        this.notificationRepository
                                            .items[index]
                                            .Title,
                                        style: TextStyle(
                                          height: 16,
                                          fontSize: 16,
                                          fontWeight: FontWeight.bold,
                                        ),
                                        maxLines: 1,
                                        overflow: TextOverflow.ellipsis,
                                      ),
                                    ),
                                    Container(
                                      alignment: Alignment.topLeft,
                                      child: Text(
                                        this.notificationRepository
                                            .items[index]
                                            .Message,
                                        style: TextStyle(
                                          color: Colors.grey,
                                          fontSize: 12,
                                          fontWeight: FontWeight.bold,
                                        ),
                                        maxLines: 3,
                                        overflow: TextOverflow.ellipsis,
                                      ),
                                    ),
                                  ],
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                      Container(
                        margin: EdgeInsets.only(
                          top: 8,
                        ),
                        alignment: Alignment.centerRight,
                        child: Text(
                          this.notificationRepository
                              .items[index]
                              .CreatedDate,
                          style: TextStyle(
                            color: Colors.grey.shade600,
                            fontSize: 12,
                            fontWeight: FontWeight.bold,
                          ),
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                        ),
                      ),
                    ],
                  ),
                );
              }),
            ),
          ),
        ],
      ),
    );
  }
}
